# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['landsatxplore']

package_data = \
{'': ['*']}

install_requires = \
['click', 'requests', 'shapely', 'tqdm']

entry_points = \
{'console_scripts': ['landsatxplore = landsatxplore.cli:cli']}

setup_kwargs = {
    'name': 'landsatxplore',
    'version': '0.12.0',
    'description': 'Search and download Landsat scenes from EarthExplorer',
    'long_description': '[![Build](https://img.shields.io/github/workflow/status/yannforget/landsatxplore/Upload%20Python%20Package?label=build&logo=github)](https://github.com/yannforget/landsatxplore/actions/workflows/python-publish.yml)\n[![Tests](https://img.shields.io/github/workflow/status/yannforget/landsatxplore/Run%20tests?label=tests&logo=github)](https://github.com/yannforget/landsatxplore/actions/workflows/run-tests.yml)\n[![codecov](https://codecov.io/gh/yannforget/landsatxplore/branch/master/graph/badge.svg?token=NwVo09Edur)](https://codecov.io/gh/yannforget/landsatxplore)\n[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1291422.svg)](https://zenodo.org/record/4543601)\n\n# Description\n\n![CLI Demo](https://raw.githubusercontent.com/yannforget/landsatxplore/master/demo.gif?s=0.5)\n\nThe **landsatxplore** Python package provides an interface to the [EarthExplorer](http://earthexplorer.usgs.gov/) portal to search and download [Landsat Collections](https://landsat.usgs.gov/landsat-collections) scenes through a command-line interface or a Python API.\n\nThe following datasets are supported:\n\n\n| Dataset Name | Dataset ID |\n|-|-|\n| Landsat 5 TM Collection 1 Level 1 | `landsat_tm_c1` |\n| Landsat 5 TM Collection 2 Level 1 | `landsat_tm_c2_l1` |\n| Landsat 5 TM Collection 2 Level 2 | `landsat_tm_c2_l2` |\n| Landsat 7 ETM+ Collection 1 Level 1 | `landsat_etm_c1` |\n| Landsat 7 ETM+ Collection 2 Level 1 | `landsat_etm_c2_l1` |\n| Landsat 7 ETM+ Collection 2 Level 2 | `landsat_etm_c2_l2` |\n| Landsat 8 Collection 1 Level 1 | `landsat_8_c1` |\n| Landsat 8 Collection 2 Level 1 | `landsat_ot_c2_l1` |\n| Landsat 8 Collection 2 Level 2 | `landsat_ot_c2_l2` |\n| Sentinel 2A | `sentinel_2a` |\n\n\n# Quick start\n\nSearching for Landsat 5 TM scenes that contains the location (12.53, -1.53) acquired during the year 1995.\n\n```\nlandsatxplore search --dataset LANDSAT_TM_C1 --location 12.53 -1.53 \\\n    --start 1995-01-01 --end 1995-12-31\n```\n\nSearch for Landsat 7 ETM scenes in Brussels with less than 5% of clouds. Save the returned results in a `.csv` file.\n\n```\nlandsatxplore search --dataset LANDSAT_ETM_C1 \\\n    --location 50.83 4.38 --clouds 5 > results.csv\n```\n\nDownloading three Landsat scenes from different datasets in the current directory.\n\n```\nlandsatxplore download LT51960471995178MPS00 LC80390222013076EDC00 LC82150682015350LGN01\n```\n\nTo use the package, Earth Explorer credentials are required ([registration](https://ers.cr.usgs.gov/register)).\n\n# Installation\n\nThe package can be installed using pip.\n\n```\npip install landsatxplore\n```\n\n# Usage\n\n**landsatxplore** can be used both through its command-line interface and as a Python module.\n\n## Command-line interface\n\n```\nlandsatxplore --help\n```\n\n```\nUsage: landsatxplore [OPTIONS] COMMAND [ARGS]...\n\nOptions:\n  --help  Show this message and exit.\n\nCommands:\n  download  Download one or several Landsat scenes.\n  search    Search for Landsat scenes.\n```\n\n### Credentials\n\nCredentials for the Earth Explorer portal can be obtained [here](https://ers.cr.usgs.gov/register/).\n\n`--username` and `--password` can be provided as command-line options or as environment variables:\n\n``` shell\nexport LANDSATXPLORE_USERNAME=<your_username>\nexport LANDSATXPLORE_PASSWORD=<your_password>\n```\n\n### Searching\n\n```\nlandsatxplore search --help\n```\n\n```\nUsage: landsatxplore search [OPTIONS]\n\n  Search for Landsat scenes.\n\nOptions:\n  -u, --username TEXT             EarthExplorer username.\n  -p, --password TEXT             EarthExplorer password.\n  -d, --dataset [landsat_tm_c1|landsat_etm_c1|landsat_8_c1|landsat_tm_c2_l1|landsat_tm_c2_l2|landsat_etm_c2_l1|landsat_etm_c2_l2|landsat_ot_c2_l1|landsat_ot_c2_l2|sentinel_2a]\n                                  Landsat data set.\n  -l, --location FLOAT...         Point of interest (latitude, longitude).\n  -b, --bbox FLOAT...             Bounding box (xmin, ymin, xmax, ymax).\n  -c, --clouds INTEGER            Max. cloud cover (1-100).\n  -s, --start TEXT                Start date (YYYY-MM-DD).\n  -e, --end TEXT                  End date (YYYY-MM-DD).\n  -o, --output [scene_id|product_id|json|csv]\n                                  Output format.\n  -m, --limit INTEGER             Max. results returned.\n  --help                          Show this message and exit.\n```\n\n### Downloading\n\n```\nlandsatxplore download --help\n```\n\n```\nUsage: landsatxplore download [OPTIONS] [SCENES]...\n\n  Download one or several Landsat scenes.\n\nOptions:\n  -u, --username TEXT    EarthExplorer username.\n  -p, --password TEXT    EarthExplorer password.\n  -d, --dataset TEXT     Dataset.\n  -o, --output PATH      Output directory.\n  -t, --timeout INTEGER  Download timeout in seconds.\n  --skip\n  --help                 Show this message and exit.\n```\n\nIf the `--dataset` is not provided, the dataset is automatically guessed from the scene identifier. Note that only the newer Landsat Product Identifiers contain information related to collection number and processing level. To download Landsat Collection 2 products, use Product IDs or set the `--dataset` option correctly.\n\n\n## API\n\n### EarthExplorer API\n\n**landsatxplore** provides an interface to the Earth Explorer JSON API. Please refer to the official ([documentation](https://earthexplorer.usgs.gov/inventory/documentation/json-api)) for possible request codes and parameters.\n\n#### Basic usage\n\n``` python\nfrom landsatxplore.api import API\n\n# Initialize a new API instance and get an access key\napi = API(username, password)\n\n# Perform a request. Results are returned in a dictionnary\nresponse = api.request(\n    \'<request_endpoint>\',\n    params={\n        "param_1": value_1,\n        "param_2": value_2\n    }\n)\n\n#\xa0Log out\napi.logout()\n```\n\nPlease refer to the official [JSON API Reference](https://m2m.cr.usgs.gov/api/docs/json/) for a list of all available requests.\n\n#### Searching for scenes\n\n``` python\nimport json\nfrom landsatxplore.api import API\n\n# Initialize a new API instance and get an access key\napi = API(username, password)\n\n# Search for Landsat TM scenes\nscenes = api.search(\n    dataset=\'landsat_tm_c1\',\n    latitude=50.85,\n    longitude=-4.35,\n    start_date=\'1995-01-01\',\n    end_date=\'1995-10-01\',\n    max_cloud_cover=10\n)\n\nprint(f"{len(scenes)} scenes found.")\n\n# Process the result\nfor scene in scenes:\n    print(scene[\'acquisition_date\'])\n    # Write scene footprints to disk\n    fname = f"{scene[\'landsat_product_id\']}.geojson"\n    with open(fname, "w") as f:\n        json.dump(scene[\'spatialCoverage\'], f)\n\napi.logout()\n```\n\nOutput:\n\n```\n6 scenes found.\n1995/08/19\n1995/08/19\n1995/08/12\n1995/08/03\n1995/08/03\n1995/02/08\n```\n\n#### Downloading scenes\n\n``` python\nfrom landsatxplore.earthexplorer import EarthExplorer\n\nee = EarthExplorer(username, password)\n\nee.download(scene_id=\'LT51960471995178MPS00\', output_dir=\'./data\')\n\nee.logout()\n```\n',
    'author': 'Yann Forget',
    'author_email': 'yannforget@mailbox.org',
    'maintainer': 'Yann Forget',
    'maintainer_email': 'yannforget@mailbox.org',
    'url': 'https://github.com/yannforget/landsatxplore',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
